Page 111 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 111

Home

    saints, and with the blood of the martyrs of Jesus: . . .
    Revelation 17:6

    And in her was found the blood of prophets, and of
    saints, and of all that were slain upon the earth.

    n 1 10.44

    The rise of a Modern Day Babylon during the 20th
    century has had the distinction of making this the
    bloodiest period in history. Above the lust for wealth and
    power, upon the part of the leaders of this infamous
    structure, has been a Satanic drive to carry out the
    Illuminist plan to destroy all traditional religion and
    replace God with the state, and an idolatrous worship of

    nature.

    long range, and universal manner that it is impossible not
    to have been the policy of a central power. The victims
    of this policy, those who believed in God as a creator,
    have numbered in the tens of millions, most of whom

    106

    Chapter 11

    Babylon's War Against God

    And I saw the woman drunken with the blood of the

    Revelation 18:24

    This plan has been carried out in such a consistent,

    have been murdered by a government that Modern Day

    Babylon brought to power.